pub trait ProgrammableTransactionBuilderExt {
// Required methods
fn update_af_oracle_pyth_feed_args(
&mut self,
pyth_state: ObjectArg,
pyth_wrapper: ObjectArg,
pfs_to_source: Vec<(ObjectArg, ObjectArg)>,
) -> Result<UpdateAfOracleArguments, Error>;
fn update_af_oracle_pyth_feed(
&mut self,
pyth_wrapper_pkg: Address,
arguments: UpdateAfOracleArguments,
) -> Result<(), Error>;
}Expand description
This is an extension trait for the following impl:
ⓘ
#[extension(pub trait ProgrammableTransactionBuilderExt)]
impl for ProgrammableTransactionBuilder
Required Methods
Sourcefn update_af_oracle_pyth_feed_args(
&mut self,
pyth_state: ObjectArg,
pyth_wrapper: ObjectArg,
pfs_to_source: Vec<(ObjectArg, ObjectArg)>,
) -> Result<UpdateAfOracleArguments, Error>
fn update_af_oracle_pyth_feed_args( &mut self, pyth_state: ObjectArg, pyth_wrapper: ObjectArg, pfs_to_source: Vec<(ObjectArg, ObjectArg)>, ) -> Result<UpdateAfOracleArguments, Error>
Construct the PTB arguments to be used in update_af_oracle_pyth_feed.
This is separate from update_af_oracle_pyth_feed since the caller may want to use some of the
arguments created here in subsequent PTB calls.
Sourcefn update_af_oracle_pyth_feed(
&mut self,
pyth_wrapper_pkg: Address,
arguments: UpdateAfOracleArguments,
) -> Result<(), Error>
fn update_af_oracle_pyth_feed( &mut self, pyth_wrapper_pkg: Address, arguments: UpdateAfOracleArguments, ) -> Result<(), Error>
Add a PythWrapper update to the PTB being built.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl ProgrammableTransactionBuilderExt for ProgrammableTransactionBuilder
impl ProgrammableTransactionBuilderExt for ProgrammableTransactionBuilder
Sourcefn update_af_oracle_pyth_feed_args(
&mut self,
pyth_state: ObjectArg,
pyth_wrapper: ObjectArg,
pfs_to_source: Vec<(ObjectArg, ObjectArg)>,
) -> Result<UpdateAfOracleArguments, Error>
fn update_af_oracle_pyth_feed_args( &mut self, pyth_state: ObjectArg, pyth_wrapper: ObjectArg, pfs_to_source: Vec<(ObjectArg, ObjectArg)>, ) -> Result<UpdateAfOracleArguments, Error>
Construct the PTB arguments to be used in update_af_oracle_pyth_feed.
This is separate from update_af_oracle_pyth_feed since the caller may want to use some of the
arguments created here in subsequent PTB calls.
Sourcefn update_af_oracle_pyth_feed(
&mut self,
pyth_wrapper_pkg: Address,
arguments: UpdateAfOracleArguments,
) -> Result<(), Error>
fn update_af_oracle_pyth_feed( &mut self, pyth_wrapper_pkg: Address, arguments: UpdateAfOracleArguments, ) -> Result<(), Error>
Add a PythWrapper update to the PTB being built.